.. _contributing:

How to Contribute
================= 
Visit our `GitHub repository <https://github.com/lanl/fiducia>`_ and look
through the list of `open issues <https://github.com/lanl/fiducia/issues>`_ to
see how you can contribute. If you find a bug, or would like to see a feature
enhancement, then open up an issue and describe it detail.